@@ -8,6 +8,8 @@
 */
 
 /* .Call calls */
+extern SEXP _vapour_find_feature_count_cpp(SEXP, SEXP, SEXP);
+extern SEXP _vapour_proj_to_wkt_cpp(SEXP);
 extern SEXP _vapour_raster_gcp_cpp(SEXP);
 extern SEXP _vapour_raster_info_cpp(SEXP, SEXP);
 extern SEXP _vapour_raster_io_cpp(SEXP, SEXP, SEXP, SEXP);
@@ -22,8 +24,11 @@ extern SEXP _vapour_vapour_read_geometry_cpp(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP,
 extern SEXP _vapour_vapour_read_names_cpp(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
 extern SEXP _vapour_vapour_report_attributes_cpp(SEXP, SEXP, SEXP);
 extern SEXP _vapour_VSI_list(SEXP);
+extern SEXP _vapour_warp_memory_cpp(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
 
 static const R_CallMethodDef CallEntries[] = {
+    {"_vapour_find_feature_count_cpp",       (DL_FUNC) &_vapour_find_feature_count_cpp,       3},
+    {"_vapour_proj_to_wkt_cpp",              (DL_FUNC) &_vapour_proj_to_wkt_cpp,              1},
     {"_vapour_raster_gcp_cpp",               (DL_FUNC) &_vapour_raster_gcp_cpp,               1},
     {"_vapour_raster_info_cpp",              (DL_FUNC) &_vapour_raster_info_cpp,              2},
     {"_vapour_raster_io_cpp",                (DL_FUNC) &_vapour_raster_io_cpp,                4},
@@ -38,6 +43,7 @@ static const R_CallMethodDef CallEntries[] = {
     {"_vapour_vapour_read_names_cpp",        (DL_FUNC) &_vapour_vapour_read_names_cpp,        6},
     {"_vapour_vapour_report_attributes_cpp", (DL_FUNC) &_vapour_vapour_report_attributes_cpp, 3},
     {"_vapour_VSI_list",                     (DL_FUNC) &_vapour_VSI_list,                     1},
+    {"_vapour_warp_memory_cpp",              (DL_FUNC) &_vapour_warp_memory_cpp,              6},
     {NULL, NULL, 0}
 };
 
